@@ -20,15 +20,19 @@
 try:
     import ibm_db_dbi as Database
 except ImportError, e:
-    raise ImportError( "ibm_db module not found. Install ibm_db module from http://code.google.com/p/ibm-db/." )
+    raise ImportError( "ibm_db module not found. Install ibm_db module from http://code.google.com/p/ibm-db/. Error: %s" % e )
 
+import datetime
 # For checking django's version
 from django import VERSION as djangoVersion
-
 import decimal
 if ( djangoVersion[0:2] > ( 1, 1 ) ):
     from django.db import utils
     import sys
+if ( djangoVersion[0:2] >= ( 1, 4) ):
+    from django.utils import timezone
+    from django.conf import settings
+    import warnings
 
 DatabaseError = Database.DatabaseError
 IntegrityError = Database.IntegrityError
@@ -99,11 +103,31 @@ class DB2CursorWrapper( Database.Cursor ):
         if row == None:
             raise StopIteration
         return row
-            
+    
+    def _format_parameters( self, parameters ):
+        parameters = list( parameters )
+        for index in range( len( parameters ) ):
+            # With raw SQL queries, datetimes can reach this function
+            # without being converted by DateTimeField.get_db_prep_value.
+            if settings.USE_TZ and isinstance( parameters[index], datetime.datetime ):
+                param = parameters[index]
+                if timezone.is_naive( param ):
+                    warnings.warn(u"Received a naive datetime (%s)"
+                              u" while time zone support is active." % param,
+                              RuntimeWarning)
+                    default_timezone = timezone.get_default_timezone()
+                    param = timezone.make_aware( param, default_timezone )
+                param = param.astimezone(timezone.utc).replace(tzinfo=None)
+                parameters[index] = param
+        return tuple( parameters )
+                
     # Over-riding this method to modify SQLs which contains format parameter to qmark. 
     def execute( self, operation, parameters = () ):
         try:
             operation = operation % ( tuple( "?" * operation.count( "%s" ) ) )
+            if ( djangoVersion[0:2] >= ( 1, 4 ) ):
+                parameters = self._format_parameters( parameters )
+                
             if ( djangoVersion[0:2] <= ( 1, 1 ) ):
                 return super( DB2CursorWrapper, self ).execute( operation, parameters )
             else:
@@ -120,6 +144,9 @@ class DB2CursorWrapper( Database.Cursor ):
     def executemany( self, operation, seq_parameters ):
         try:
             operation = operation % ( tuple( "?" * operation.count( "%s" ) ) )
+            if ( djangoVersion[0:2] >= ( 1, 4 ) ):
+                seq_parameters = [ self._format_parameters( parameters ) for parameters in seq_parameters ]
+                
             if ( djangoVersion[0:2] <= ( 1, 1 ) ):
                 return super( DB2CursorWrapper, self ).executemany( operation, seq_parameters )
             else:
@@ -132,3 +159,40 @@ class DB2CursorWrapper( Database.Cursor ):
         except ( IndexError, TypeError ):
             return None
     
+    # Over-riding this method to modify result set containing datetime and time zone support is active
+    def fetchone( self ):
+        row = super( DB2CursorWrapper, self ).fetchone()
+        if row is None:
+            return row
+        else:
+            return self._fix_return_data( row )
+    
+    # Over-riding this method to modify result set containing datetime and time zone support is active
+    def fetchmany( self, size=0 ):
+        rows = super( DB2CursorWrapper, self ).fetchmany( size )
+        if rows is None:
+            return rows
+        else:
+            return [self._fix_return_data( row ) for row in rows]
+    
+    # Over-riding this method to modify result set containing datetime and time zone support is active
+    def fetchall( self ):
+        rows = super( DB2CursorWrapper, self ).fetchall()
+        if rows is None:
+            return rows
+        else:
+            return [self._fix_return_data( row ) for row in rows]
+        
+    # This method to modify result set containing datetime and time zone support is active   
+    def _fix_return_data( self, row ):
+        row = list( row )
+        index = -1
+        if ( djangoVersion[0:2] >= ( 1, 4 ) ):
+            for value, desc in zip( row, self.description ):
+                index = index + 1
+                if ( desc[1] == Database.DATETIME ):
+                    if settings.USE_TZ and value is not None and timezone.is_naive( value ):
+                        value = value.replace( tzinfo=timezone.utc )
+                        row[index] = value
+                      
+        return tuple( row )
\ No newline at end of file
